// crytographe.cpp: implementation of the crytographe class.
//
//////////////////////////////////////////////////////////////////////

#include "cryptographe.h"
#include <string.h>
#include <iostream>
#include <fstream>
#include <iomanip>
using namespace std;
//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////


cryptographe::cryptographe(const char* id, const char* name1, const char* name2, char cle):key(cle){
	identity=new char[strlen(id)+1];
	in_file=new char[strlen(name1)+1];
	out_file=new char[strlen(name2)+1];
	strcpy(identity,id);
	strcpy(in_file,name1);
	strcpy(out_file,name2);
	cout<<"----------- CRYPTOGRAPHE -----------"<<endl
		<<"-                                   "<<endl
		<<"- id  : "<<identity<<endl
		<<"- in  : "<<in_file<<endl
		<<"- out : "<<out_file<<endl;
}

cryptographe::~cryptographe(){
	delete[] identity;
	delete[] in_file;
	delete[] out_file;
}

//cryptage

void cryptographe::encrypt() const{
	if (is_encrypted()) {
		cout<<"encrypt -- warning :: the file has already been encrypted once"<<endl;
	}
	//p147 ifstream::
	ifstream fin(in_file);
	//p128 ios:: 
	if (fin.fail()) {
		cout<<"encrypt -- problem with file "<<in_file<<endl;
		return;
	}
	//p136 ofstream
	ofstream fout(out_file);
	//p139
	if (fout.fail()) {
		cout<<"encrypt -- problem with file "<<out_file<<endl;
		return;
	}
	
	char c;
	// add encrypted KEYWORD and identity
	cout<<"encrypt -- file "<<in_file<<" in "<<out_file<<endl;
	fout<<"ENCRYPTED"<<identity<<endl;
	//p128 ios::
	while(!fin.eof()){
		//p144
		c=fin.get();
		if (fin) {
			int x=int(c+key);
			fout<<x<<" ";
			cout<<"*";
		}
	}
	cout<<"encrypt -- done"<<endl;
}

//DECRYPTAGE
void cryptographe::decrypt() const{
	if (!is_encrypted()) {
		cout<<"decrypt -- warning :: the file has not been encrypted"<<endl;
		return;
	}
	if (!is_valid_identity()) {
		cout<<"decrypt -- no access :: bad identity"<<endl;
		return;
	}
	ifstream fin(in_file);
	if (fin.fail()) {
		cout<<"decrypt -- problem with file "<<in_file<<endl;
		return;
	}
	ofstream fout(out_file);
	if (fout.fail()) {
		cout<<"decrypt -- problem with file "<<out_file<<endl;
		return;
	}
	
	char c;
	// add encrypted KEYWORD and identity
	cout<<"decrypt -- file "<<in_file<<" in "<<out_file<<endl;
	
	// ignorer le keyword + identity
	//p146
	fin.ignore(1000,'\n');
	while(!fin.eof()){
		int x;
		fin>>x;
		if (fin) {
			c=char(x-key);
			fout<<c;
			cout<<"#";
		}
	}
	cout<<"decrypt -- done"<<endl;
}

//affichage d'un fichier mode texte
void cryptographe::look_at_file(const char* file) const{
	ifstream fin(file);
	if (fin.fail()) {
		cout<<"look_at_file -- problem with file "<<file<<endl;
		return;
	}
	cout<<"--- file::"<<file<<" ---"<<endl;
	while(!fin.eof()){
		char c;
		c=fin.get();
		if (fin) {
			cout<<c;
		}
	}
	cout<<endl<<"--- end of file::"<<file<<" ---"<<endl;
}

void cryptographe::look_at_in_file() const{
	look_at_file(in_file);
}

void cryptographe::look_at_out_file() const{
	look_at_file(out_file);
}


//test ouverture OK ET prsence ENCRYPTED
bool cryptographe::is_encrypted() const{
	ifstream fin(in_file);
	if (fin.fail()) {
		cout<<"problem with file "<<in_file<<endl;
		return false;
	}
	const char keyword[]="ENCRYPTED";
	int i=0;
	char c;
	while (keyword[i]!='\0'){
		c=fin.get();
		if (!c || c!=keyword[i]) return false;
		i++;
	}
	return true;
}



bool cryptographe::is_valid_identity() const{
	ifstream fin(in_file,ios::binary);
	if (fin.fail()) {
		cout<<"problem with file "<<in_file<<endl;
		return false;
	}
	const char keyword[]="ENCRYPTED";
	int i=0;
	char c;
	while (keyword[i]!='\0'){
		c=fin.get();
		if (!c || c!=keyword[i]) return false;
		i++;
	}

	//fin.eatwhite();

	i=0;
	while (identity[i]!='\0'){
		c=fin.get();
		if (!c || c!=identity[i]) return false;
		i++;
	}
	return true;
}
